==> finaluna-api-3.0.0.zip: finaluna-api/sources/jp/finaluna/api/type/StringCode.java <==
/*
 * Copyright (C) 2010 NTT DATA Corporation.
 */
package jp.finaluna.api.type;

/**
 * Œ蕶ێ^B
 * 
 * <p>
 * Œ蕶ێBftHg̍ő啶50*1024*1024Bő啶𒴂ꍇAFinalunaSysExceptionthrowB
 * </p>
 * 
 * @author NTTf[^
 * @version $Revision: 38309 $ $Date: 2010-03-18 17:14:55 +0900 $
 * 
 */
@Rcsid("$Revision: 38309 $ $Date: 2010-03-18 17:14:55 +0900 $")
public interface StringCode extends CodeType, CharSequenceType, Comparable < StringCode >, Copiable < StringCode > {

    /**
     * <p>
     * ̐̕擪݂̂啶ɕϊB
     * </p>
     * 
     * @return ϊ
     */
    StringCode capitalize();

    /**
     * <p>
     * ̕񂪎w肳ꂽ܂ޏꍇɌtrueԂB
     * </p>
     * 
     * @param searchSequence 
     * @return w肳ꂽ񂪊܂܂ꍇ<code>true</code>A ܂܂Ȃꍇ<code>false</code>B
     */
    boolean contains(CharSequenceType searchSequence);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽڔŏIĂ邩ǂ𔻒肷B
     * </p>
     * 
     * @param suffix ڔ
     * @return w肳ꂽڔŏIĂꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean endsWith(CharSequenceType suffix);

    /**
     * <p>
     * ̕񂪁ArΏۂ̕ƓǂA 啶A̋ʂȂɔ肷B
     * </p>
     * 
     * @param compareSequence rΏە
     * @return rΏۂ̕Ɠꍇ<code>true</code>A Ȃꍇ<code>false</code>B
     */
    boolean equalsIgnoreCase(CharSequenceType compareSequence);

    /**
     * <p>
     * ̕ŁAw肳ꂽ񂪍ŏɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchSequence 
     * @return CfbNX
     */
    int indexOf(CharSequenceType searchSequence);

    /**
     * <p>
     * wCfbNXȍ~ŁA񂪍ŏɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchSequence 
     * @param fromIndex JnCfbNX
     * @return oꂽCfbNX
     */
    int indexOf(CharSequenceType searchSequence, int fromIndex);

    /**
     * <p>
     * ̕񂪁Ap݂̂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return p݂̂ō\Ăꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean isAlpha();

    /**
     * <p>
     * ̕񂪁Â݂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return ݂̂ō\Ăꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean isNumeric();

    /**
     * <p>
     * ̕񂪁Ap݂̂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return p݂̂ō\Ăꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean isNumericAlpha();

    /**
     * <p>
     * ̕ŁAw肳ꂽ񂪍ŌɏoʒũCfbNX擾B
     * </p>
     * 
     * @param searchSequence 
     * @return oꂽCfbNX
     */
    int lastIndexOf(CharSequenceType searchSequence);

    /**
     * <p>
     * wCfbNXȑOŁA񂪍ŏɏoʒũCfbNX擾B
     * </p>
     * 
     * @param searchSequence 
     * @param fromIndex JnCfbNX
     * @return oꂽCfbNX
     */
    int lastIndexOf(CharSequenceType searchSequence, int fromIndex);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽK\ƈv邩ǂ𔻒肷B
     * </p>
     * 
     * @param regex K\
     * @return w肳ꂽK\ƈvꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean matches(CharSequenceType regex);

    /**
     * <p>
     * ̎̕w肳ꂽuΏەw肳ꂽuɒuԂB
     * </p>
     * 
     * @param target uΏە
     * @param replacement u
     * @return u㕶
     */
    StringCode replace(CharSequenceType target, CharSequenceType replacement);

    /**
     * <p>
     * w肳ꂽK\ɈvÅ̕eɑ΂Aw肳ꂽusԂB
     * </p>
     * 
     * @param regex ̕Ƃ̈v𔻒肷鐳K\
     * @param replacement uV[PX
     * @return u㕶
     */
    StringCode replaceAll(CharSequenceType regex, CharSequenceType replacement);

    /**
     * <p>
     * w肵񂪁A̕ɑ݂邩ǂ𔻒肷B
     * </p>
     * 
     * @param searchSequence 
     * @return Ɍ񂪑݂ꍇ<code>true</code>A ݂Ȃꍇ<code>false</code>B
     */
    boolean search(CharSequenceType searchSequence);

    /**
     * <p>
     * ̕Aw肳ꂽK\ɈvʒuŕԂB
     * </p>
     * 
     * @param regex K\̋؂蕶
     * @return 㕶
     */
    StringCode[] split(CharSequenceType regex);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽړŎn܂邩ǂ𔻒肷B
     * </p>
     * 
     * @param prefix ړ
     * @return w肳ꂽړŎn܂ꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean startsWith(CharSequenceType prefix);

    /**
     * <p>
     * ̕̕ԂB
     * </p>
     * 
     * @param beginIndex ̐؂oJnCfbNX
     * @return 
     */
    StringCode subString(int beginIndex);

    /**
     * <p>
     * ̕̕ԂB
     * </p>
     * 
     * @param beginIndex ̐؂oJnCfbNX
     * @param endIndex ̐؂oICfbNX
     * @return 
     */
    StringCode subString(int beginIndex, int endIndex);

    /**
     * <p>
     * ̕AׂďɕϊB
     * </p>
     * 
     * @return ϊ
     */
    StringCode toLowerCase();

    /**
     * <p>
     * ̕Aׂđ啶ɕϊB
     * </p>
     * 
     * @return ϊ
     */
    StringCode toUpperCase();

    /**
     * <p>
     * ̐̕擪Ɩ̋󔒂菜^Ԃ܂B
     * </p>
     * 
     * @return Ő󔒂菜
     */
    StringCode trim();

}

==> finaluna-api-3.2.0.zip: finaluna-api/sources/jp/finaluna/api/type/StringCode.java <==
/*
 * Copyright (C) 2010 NTT DATA Corporation.
 */
package jp.finaluna.api.type;

/**
 * Œ蕶ێ^B
 * 
 * <p>
 * Œ蕶ێBftHg̍ő啶50*1024*1024Bő啶𒴂ꍇAFinalunaSysExceptionthrowB
 * </p>
 * 
 * @author NTTf[^
 * @version $Revision: 50655 $ $Date: 2010-12-17 13:18:15 +0900 $
 * 
 */
@Rcsid("$Revision: 50655 $ $Date: 2010-12-17 13:18:15 +0900 $")
public interface StringCode extends CodeType, CharSequenceType, Comparable < StringCode >, Copiable < StringCode > {

    /**
     * <p>
     * ̐̕擪݂̂啶ɕϊBϊΏۂ̓̕At@xbĝ݂ƂB
     * </p>
     * 
     * @return ϊ
     */
    StringCode capitalize();

    /**
     * <p>
     * ̕񂪎w肳ꂽ܂ޏꍇɌtrueԂB
     * </p>
     * 
     * @param searchSequence 
     * @return w肳ꂽ񂪊܂܂ꍇ<code>true</code>A ܂܂Ȃꍇ<code>false</code>B
     */
    boolean contains(CharSequenceType searchSequence);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽڔŏIĂ邩ǂ𔻒肷B
     * </p>
     * 
     * @param suffix ڔ
     * @return w肳ꂽڔŏIĂꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean endsWith(CharSequenceType suffix);

    /**
     * <p>
     * ̕񂪁ArΏۂ̕ƓǂA 啶A̋ʂȂɔ肷BrΏۂ̓̕At@xbĝ݂ƂB
     * </p>
     * 
     * @param compareSequence rΏە
     * @return rΏۂ̕Ɠꍇ<code>true</code>A Ȃꍇ<code>false</code>B
     */
    boolean equalsIgnoreCase(CharSequenceType compareSequence);

    /**
     * <p>
     * ̕ŁAw肳ꂽ񂪍ŏɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchSequence 
     * @return CfbNX
     */
    int indexOf(CharSequenceType searchSequence);

    /**
     * <p>
     * wCfbNXȍ~ŁA񂪍ŏɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchSequence 
     * @param fromIndex JnCfbNX
     * @return oꂽCfbNX
     */
    int indexOf(CharSequenceType searchSequence, int fromIndex);

    /**
     * <p>
     * ̕񂪁Ap݂̂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return p݂̂ō\Ăꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean isAlpha();

    /**
     * <p>
     * ̕񂪁Â݂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return ݂̂ō\Ăꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean isNumeric();

    /**
     * <p>
     * ̕񂪁Ap݂̂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return p݂̂ō\Ăꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean isNumericAlpha();

    /**
     * <p>
     * ̕ŁAw肳ꂽ񂪍ŌɏoʒũCfbNX擾B
     * </p>
     * 
     * @param searchSequence 
     * @return oꂽCfbNX
     */
    int lastIndexOf(CharSequenceType searchSequence);

    /**
     * <p>
     * wCfbNXȑOŁA񂪍ŏɏoʒũCfbNX擾B
     * </p>
     * 
     * @param searchSequence 
     * @param fromIndex JnCfbNX
     * @return oꂽCfbNX
     */
    int lastIndexOf(CharSequenceType searchSequence, int fromIndex);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽK\ƈv邩ǂ𔻒肷B
     * </p>
     * 
     * @param regex K\
     * @return w肳ꂽK\ƈvꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean matches(CharSequenceType regex);

    /**
     * <p>
     * ̎̕w肳ꂽuΏەw肳ꂽuɒuԂB
     * </p>
     * 
     * @param target uΏە
     * @param replacement u
     * @return u㕶
     */
    StringCode replace(CharSequenceType target, CharSequenceType replacement);

    /**
     * <p>
     * w肳ꂽK\ɈvÅ̕eɑ΂Aw肳ꂽusԂB
     * </p>
     * 
     * @param regex ̕Ƃ̈v𔻒肷鐳K\
     * @param replacement uV[PX
     * @return u㕶
     */
    StringCode replaceAll(CharSequenceType regex, CharSequenceType replacement);

    /**
     * <p>
     * w肵񂪁A̕ɑ݂邩ǂ𔻒肷B
     * </p>
     * 
     * @param searchSequence 
     * @return Ɍ񂪑݂ꍇ<code>true</code>A ݂Ȃꍇ<code>false</code>B
     */
    boolean search(CharSequenceType searchSequence);

    /**
     * <p>
     * ̕Aw肳ꂽK\ɈvʒuŕԂB
     * </p>
     * 
     * @param regex K\̋؂蕶
     * @return 㕶
     */
    StringCode[] split(CharSequenceType regex);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽړŎn܂邩ǂ𔻒肷B
     * </p>
     * 
     * @param prefix ړ
     * @return w肳ꂽړŎn܂ꍇ<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean startsWith(CharSequenceType prefix);

    /**
     * <p>
     * ̕̕ԂB
     * </p>
     * 
     * @param beginIndex ̐؂oJnCfbNX
     * @return 
     */
    StringCode subString(int beginIndex);

    /**
     * <p>
     * ̕̕ԂB
     * </p>
     * 
     * @param beginIndex ̐؂oJnCfbNX
     * @param endIndex ̐؂oICfbNX
     * @return 
     */
    StringCode subString(int beginIndex, int endIndex);

    /**
     * <p>
     * ̕AׂďɕϊBϊΏۂ̓̕At@xbĝ݂ƂB
     * </p>
     * 
     * @return ϊ
     */
    StringCode toLowerCase();

    /**
     * <p>
     * ̕Aׂđ啶ɕϊBϊΏۂ̓̕At@xbĝ݂ƂB
     * </p>
     * 
     * @return ϊ
     */
    StringCode toUpperCase();

    /**
     * <p>
     * ̐̕擪Ɩ̋󔒂菜^Ԃ܂B
     * </p>
     * 
     * @return Ő󔒂菜
     */
    StringCode trim();

}
